macro_rules! min_max_partial {
($x:expr) => { ... };
($($xs:expr),+) => { ... };
}Expand description
Returns the minimum and maximum element of the arguments. Uses partial_min_max::min for comparison.
macro_rules! min_max_partial {
($x:expr) => { ... };
($($xs:expr),+) => { ... };
}Returns the minimum and maximum element of the arguments. Uses partial_min_max::min for comparison.